@@ -43,7 +43,7 @@ GWEN_LIST2_FUNCTIONS(GWEN_SIGNAL, GWEN_Signal)
 GWEN_LIST2_FUNCTIONS(GWEN_SLOT, GWEN_Slot)
 
 
-GWEN_SIGNALOBJECT *GWEN_SignalObject_new() {
+GWEN_SIGNALOBJECT *GWEN_SignalObject_new(void) {
   GWEN_SIGNALOBJECT *so;
 
   GWEN_NEW_OBJECT(GWEN_SIGNALOBJECT, so);
