@@ -51,6 +51,7 @@ GWEN_IDMAP *GWEN_IdMap_new(GWEN_IDMAP_ALGO algo) {
   case GWEN_IdMapAlgo_Hex4:
     GWEN_IdMapHex4_Extend(map);
     break;
+  case GWEN_IdMapAlgo_Unknown:
   default:
     DBG_ERROR(GWEN_LOGDOMAIN, "Unknown algo %d", algo);
     GWEN_IdMap_free(map);
@@ -134,6 +135,7 @@ void GWEN_IdMap_Clear(GWEN_IDMAP *map) {
   case GWEN_IdMapAlgo_Hex4:
     GWEN_IdMapHex4_Extend(map);
     break;
+  case GWEN_IdMapAlgo_Unknown:
   default:
     DBG_ERROR(GWEN_LOGDOMAIN, "Unknown algo %d", map->algo);
   }
@@ -401,7 +403,8 @@ GWEN_IDMAP_HEX4_TABLE *GWEN_IdMapHex4__GetFirstTable(GWEN_IDMAP_HEX4_TABLE *t,
   uint32_t id;
   int i;
 
-  id=*pid;
+  /* id=*pid; */
+  id=0;
   for (i=0; i<16; i++) {
     if (t->ptrs[i]) {
       uint32_t lid;
