@@ -24,7 +24,7 @@
 GWEN_LIST_FUNCTIONS(GWEN_CRYPTHEAD, GWEN_CryptHead)
 
 
-GWEN_CRYPTHEAD *GWEN_CryptHead_new() {
+GWEN_CRYPTHEAD *GWEN_CryptHead_new(void) {
   GWEN_CRYPTHEAD *ch;
 
   GWEN_NEW_OBJECT(GWEN_CRYPTHEAD, ch);
