@@ -72,33 +72,33 @@ void GWEN_Gui_GetRawText(const GWEN_GUI *gui, const char *text, GWEN_BUFFER *tbu
  * Please see @ref GWEN_Gui_Print for details.
  */
 typedef int GWENHYWFAR_CB (*GWEN_GUI_PRINT_FN)(GWEN_GUI *gui,
-				 const char *docTitle,
-				 const char *docType,
-				 const char *descr,
-				 const char *text,
-				 uint32_t guiid);
+					       const char *docTitle,
+					       const char *docType,
+					       const char *descr,
+					       const char *text,
+					       uint32_t guiid);
 
 /**
  * This function retrieves a pasword or pin.
  */
 typedef int GWENHYWFAR_CB (*GWEN_GUI_GETPASSWORD_FN)(GWEN_GUI *gui,
-				       uint32_t flags,
-				       const char *token,
-				       const char *title,
-				       const char *text,
-				       char *buffer,
-				       int minLen,
-				       int maxLen,
-				       uint32_t guiid);
+						     uint32_t flags,
+						     const char *token,
+						     const char *title,
+						     const char *text,
+						     char *buffer,
+						     int minLen,
+						     int maxLen,
+						     uint32_t guiid);
 
 /**
  * This functions sets the status of a password.
  */
 typedef int GWENHYWFAR_CB (*GWEN_GUI_SETPASSWORDSTATUS_FN)(GWEN_GUI *gui,
-					     const char *token,
-					     const char *pin,
-					     GWEN_GUI_PASSWORD_STATUS status,
-					     uint32_t guiid);
+							   const char *token,
+							   const char *pin,
+							   GWEN_GUI_PASSWORD_STATUS status,
+							   uint32_t guiid);
 
 
 /**
@@ -114,33 +114,33 @@ typedef int GWENHYWFAR_CB (*GWEN_GUI_SETPASSWORDSTATUS_FN)(GWEN_GUI *gui,
  *
  */
 typedef int GWENHYWFAR_CB (*GWEN_GUI_LOG_HOOK_FN)(GWEN_GUI *gui,
-				    const char *logDomain,
-				    GWEN_LOGGER_LEVEL priority, const char *s);
+                                                  const char *logDomain,
+                                                  GWEN_LOGGER_LEVEL priority, const char *s);
 
 typedef int GWENHYWFAR_CB (*GWEN_GUI_WAITFORSOCKETS_FN)(GWEN_GUI *gui,
-					  GWEN_SOCKET_LIST2 *readSockets,
-					  GWEN_SOCKET_LIST2 *writeSockets,
-					  int msecs,
-					  uint32_t guiid);
+                                                        GWEN_SOCKET_LIST2 *readSockets,
+                                                        GWEN_SOCKET_LIST2 *writeSockets,
+                                                        int msecs,
+                                                        uint32_t guiid);
 
 typedef int GWENHYWFAR_CB (*GWEN_GUI_CHECKCERT_FN)(GWEN_GUI *gui,
-				     const GWEN_SSLCERTDESCR *cert,
-				     GWEN_SYNCIO *sio,
-				     uint32_t guiid);
+                                                   const GWEN_SSLCERTDESCR *cert,
+                                                   GWEN_SYNCIO *sio,
+                                                   uint32_t guiid);
 
 typedef int GWENHYWFAR_CB (*GWEN_GUI_KEYDATAFROMTEXT_OPENSSL_FN)(GWEN_GUI *gui,
-						   const char *text,
-						   unsigned char *buffer,
-						   unsigned int bufLength);
+                                                                 const char *text,
+                                                                 unsigned char *buffer,
+                                                                 unsigned int bufLength);
 
 typedef int GWENHYWFAR_CB (*GWEN_GUI_EXEC_DIALOG_FN)(GWEN_GUI *gui,
-				       GWEN_DIALOG *dlg,
-				       uint32_t guiid);
+						     GWEN_DIALOG *dlg,
+						     uint32_t guiid);
 
 
 typedef int GWENHYWFAR_CB (*GWEN_GUI_OPEN_DIALOG_FN)(GWEN_GUI *gui,
-				       GWEN_DIALOG *dlg,
-				       uint32_t guiid);
+                                                     GWEN_DIALOG *dlg,
+                                                     uint32_t guiid);
 
 typedef int GWENHYWFAR_CB (*GWEN_GUI_CLOSE_DIALOG_FN)(GWEN_GUI *gui, GWEN_DIALOG *dlg);
 
@@ -148,24 +148,24 @@ typedef int GWENHYWFAR_CB (*GWEN_GUI_RUN_DIALOG_FN)(GWEN_GUI *gui, GWEN_DIALOG *
 
 
 typedef int GWENHYWFAR_CB (*GWEN_GUI_READ_DIALOG_PREFS_FN)(GWEN_GUI *gui, const char *groupName, const char *altName,
-					     GWEN_DB_NODE **pDb);
+							   GWEN_DB_NODE **pDb);
 
 typedef int GWENHYWFAR_CB (*GWEN_GUI_WRITE_DIALOG_PREFS_FN)(GWEN_GUI *gui, const char *groupName,
-					      GWEN_DB_NODE *db);
+							    GWEN_DB_NODE *db);
 
 
 typedef int GWENHYWFAR_CB (*GWEN_GUI_GET_FILENAME_FN)(GWEN_GUI *gui,
-                                        const char *caption,
-					GWEN_GUI_FILENAME_TYPE fnt,
-					uint32_t flags,
-					const char *patterns,
-					GWEN_BUFFER *pathBuffer,
-					uint32_t guiid);
+						      const char *caption,
+						      GWEN_GUI_FILENAME_TYPE fnt,
+						      uint32_t flags,
+						      const char *patterns,
+						      GWEN_BUFFER *pathBuffer,
+						      uint32_t guiid);
 
 typedef int GWENHYWFAR_CB (*GWEN_GUI_GETSYNCIO_FN)(GWEN_GUI *gui, const char *url,
-				     const char *defaultProto,
-                                     int defaultPort,
-				     GWEN_SYNCIO **pSio);
+						   const char *defaultProto,
+						   int defaultPort,
+						   GWEN_SYNCIO **pSio);
 
 
 /*@}*/
@@ -369,6 +369,15 @@ typedef int (*GWEN_GUI_PROGRESS_ADVANCE_FN)(GWEN_GUI *gui,
 					    uint32_t id,
 					    uint64_t progress);
 
+
+/**
+ * Please see @ref GWEN_Gui_ProgressSetTotal for details.
+ *
+ */
+typedef int (*GWEN_GUI_PROGRESS_SETTOTAL_FN)(GWEN_GUI *gui,
+					     uint32_t id,
+					     uint64_t total);
+
 /**
  * Please see @ref GWEN_Gui_ProgressLog for details.
  *
@@ -418,6 +427,10 @@ GWENHYWFAR_API
 GWEN_GUI_PROGRESS_ADVANCE_FN
 GWEN_Gui_SetProgressAdvanceFn(GWEN_GUI *gui, GWEN_GUI_PROGRESS_ADVANCE_FN f);
 
+GWENHYWFAR_API
+GWEN_GUI_PROGRESS_SETTOTAL_FN
+GWEN_Gui_SetProgressSetTotalFn(GWEN_GUI *gui, GWEN_GUI_PROGRESS_SETTOTAL_FN f);
+
 GWENHYWFAR_API
 GWEN_GUI_PROGRESS_LOG_FN
 GWEN_Gui_SetProgressLogFn(GWEN_GUI *gui, GWEN_GUI_PROGRESS_LOG_FN f);
